==> dl.php?src=linea21_1_0.zip: linea21/public/rss.php <==
<?php
error_reporting(E_ALL);
include_once('../config/define_release.php');
include_once('../config/define_db.php'); 
include_once('../public/'.SQL.'.inc.php'); 

include_once('../lib/items.php');

////////////////////////////////////////
/// Connexion Mysql
///////////////////
include_once('../class/system/class.'.SQL.'.php');
$sql_entity=SQL;
$sql_object = new $sql_entity;
$sql_object -> DBInitialise();
$sql_object -> DBConnexion();
///////////////////

function SQL_getRSSformatedNews() {
	$requete = 	"SELECT news_id, news_title, CONCAT(LEFT(CONCAT(news_header, ' ', news_body),247), '...') AS news_description, theme_name, ".
				"DATE_FORMAT(news_published_date, '%Y-%m-%d\\T%H:%i:%s+00:00') AS news_published_date_display, ".
				"DATE_FORMAT(news_date_crea, '%d-%m-%Y') AS news_date_crea_display, user_login ".
				"FROM " . T_NEWS . " ".
				"LEFT OUTER JOIN " . T_THEME. " ON news_theme=theme_id ".
				"LEFT OUTER JOIN " . T_USER. " ON news_posted_by=user_id ".
				" WHERE news_statut='P' ".
				"ORDER BY news_published_date DESC LIMIT 0 , 15;";
	return $requete;
}
			
$data=$sql_object -> DBSelect(SQL_getRSSformatedNews());

$li_items='';
$content='';
if($data!=0) {
	
	for($i=0; $i<count($data); $i++) {
		$news_id=$data[$i]['news_id'];
		$news_title=utf8_encode($data[$i]['news_title']);
		$news_posted_by=utf8_encode($data[$i]['user_login']);
		$news_description=utf8_encode($data[$i]['news_description']);
		$news_theme=utf8_encode($data[$i]['theme_name']);
		$news_date=$data[$i]['news_published_date_display'];
		$link_news=array ('rub'=>$GLOBALS['links']['actualite']['linkvalue'], 'id'=>$news_id);
		
		$li_items.='<rdf:li resource="'.LINEA_ROOT_URL.HrefMaker($link_news).'" />'.END_LINE;


		$content.='<item rdf:about="'.LINEA_ROOT_URL.HrefMaker($link_news).'">'.END_LINE;
		$content.='<title>'.$news_title.'</title>'.END_LINE;
		$content.='<link>'.LINEA_ROOT_URL.HrefMaker($link_news).'</link>'.END_LINE;
		$content.='<dc:date>'.$news_date.'</dc:date>'.END_LINE;
		$content.='<dc:subject>'.$news_theme.'</dc:subject>'.END_LINE;
		$content.='<dc:publisher>'.utf8_encode(SITE_CITY_NAME).'</dc:publisher>'.END_LINE;
		$content.='<dc:creator>'.$news_posted_by.'</dc:creator>'.END_LINE;
		$content.='<description>'.END_LINE;
		$content.=$news_description;
		$content.='</description>'.END_LINE;
		$content.='</item>'.END_LINE;
	}
}





/**
* HEADER RSS
****************************************************************/
header('Content-Type: text/xml');
echo '<?xml version="1.0" encoding="UTF-8"?>'.END_LINE;


echo '<rdf:RDF
	xmlns="http://purl.org/rss/1.0/"
	xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
	xmlns:dc="http://purl.org/dc/elements/1.1/"
	xmlns:sy="http://purl.org/rss/1.0/modules/syndication/"
	xmlns:admin="http://webns.net/mvcb/"
	xmlns:content="http://purl.org/rss/1.0/modules/content/"
>'.END_LINE;
  
echo '<channel rdf:about="'.utf8_encode(LINEA_ROOT_URL).'">'.END_LINE;
echo '<title>'.utf8_encode('Actualits - '.SITE_CITY_NAME).'</title>'.END_LINE;
echo '<link>'.utf8_encode(LINEA_ROOT_URL).'</link>'.END_LINE;
echo '<description>'.utf8_encode('Actualits - '.SITE_CITY_NAME).'</description>'.END_LINE;
echo '<dc:language>'.strtolower(LANGUAGE).'</dc:language>'.END_LINE;
echo '<dc:publisher>'.utf8_encode(SITE_CITY_NAME).'</dc:publisher>'.END_LINE;
echo '<dc:creator>'.utf8_encode(SITE_LINEA_NAME.' (mailto:'.MAIL_LINEA.')').'</dc:creator>'.END_LINE;
echo '<dc:rights>Copyrights '.date("Y").'</dc:rights>'.END_LINE;
echo '<dc:date>'.date('Y-m-d\\TH:i:s+00:00').'</dc:date>'.END_LINE;
echo '<admin:generatorAgent rdf:resource="'.utf8_encode(SITE_LINEA_URL).'"/>'.END_LINE;
echo '<admin:errorReportsTo rdf:resource="mailto:'.SITE_CITY_MAIL.'"/>'.END_LINE;
echo '<sy:updatePeriod>daily</sy:updatePeriod>'.END_LINE;
echo '<sy:updateFrequency>2</sy:updateFrequency>'.END_LINE;
echo '<sy:updateBase>2000-01-01</sy:updateBase>'.END_LINE;

echo '<image rdf:resource="http://www.linea21.com/logo_linea.gif" />'.END_LINE;

# LISTES ITEMS
echo '<items>'.END_LINE;
echo '<rdf:Seq>'.END_LINE;
echo $li_items.END_LINE;
echo '</rdf:Seq>'.END_LINE;
echo '</items>'.END_LINE;
echo '</channel>'.END_LINE;


echo $content;

  
/**
* FOOTER RSS
**********************************************************/

echo '</rdf:RDF>'.END_LINE;
?>

==> dl.php?src=linea21_1_1.zip: linea21/public/rss.php <==
<?php
include_once('../config/server.php');
include_once('../config/define_release.php');
include_once('../config/define_db.php'); 
include_once('../public/'.SQL.'.inc.php'); 
include_once('../languages/' . LANGUAGE. '/lang_common.' . CHARSET . '.php');
include_once('../lib/items.php');
include_once('../lib/lib_common.php');

////////////////////////////////////////
/// Connexion Mysql
///////////////////
include_once('../class/system/class.'.SQL.'.php');
$sql_entity=SQL;
$sql_object = new $sql_entity;
$sql_object -> DBInitialise();
$sql_object -> DBConnexion();
///////////////////
	
$data=$sql_object -> DBSelect(SQL_getRSSformatedNews());

$li_items='';
$content='';
if($data!=0) {
	
	for($i=0; $i<count($data); $i++) {
		$news_id=$data[$i]['news_id'];
		$news_title=$data[$i]['news_title'];
		$news_posted_by=$data[$i]['user_login'];
		$news_description=$data[$i]['news_description'];
		$news_theme=$data[$i]['theme_name'];
		$news_date=$data[$i]['news_published_date_display'];
		$link_news=array ('rub'=>$GLOBALS['links']['actualite']['linkvalue'], 'id'=>$news_id);
		
		$li_items.='<rdf:li resource="'.SITE_CITY_URL.HrefMaker($link_news).'" />'.END_LINE;


		$content.='<item rdf:about="'.SITE_CITY_URL.HrefMaker($link_news).'">'.END_LINE;
		$content.='<title>'.$news_title.'</title>'.END_LINE;
		$content.='<link>'.SITE_CITY_URL.HrefMaker($link_news).'</link>'.END_LINE;
		$content.='<dc:date>'.$news_date.'</dc:date>'.END_LINE;
		$content.='<dc:subject>'.$news_theme.'</dc:subject>'.END_LINE;
		$content.='<dc:publisher>'.SITE_CITY_NAME.'</dc:publisher>'.END_LINE;
		$content.='<dc:creator>'.$news_posted_by.'</dc:creator>'.END_LINE;
		$content.='<description>'.END_LINE;
		$content.=$news_description;
		$content.='</description>'.END_LINE;
		$content.='</item>'.END_LINE;
	}
}





/**
* HEADER RSS
****************************************************************/
header('Content-Type: text/xml');
echo "<?xml version=\"1.0\" encoding=\"UTF-8\"?>".END_LINE;


echo '<rdf:RDF
	xmlns="http://purl.org/rss/1.0/"
	xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
	xmlns:dc="http://purl.org/dc/elements/1.1/"
	xmlns:sy="http://purl.org/rss/1.0/modules/syndication/"
	xmlns:admin="http://webns.net/mvcb/"
	xmlns:content="http://purl.org/rss/1.0/modules/content/"
>'.END_LINE;
  
echo '<channel rdf:about="'.SITE_CITY_URL.'">'.END_LINE;
echo '<title>'.$GLOBALS['lang']['divers']['actu_left'] . ' - '.SITE_CITY_NAME.'</title>'.END_LINE;
echo '<link>'.SITE_CITY_URL.'</link>'.END_LINE;
echo '<description>'.$GLOBALS['lang']['divers']['actu_left'] . ' - '.SITE_CITY_NAME.'</description>'.END_LINE;
echo '<dc:language>'.strtolower(LANGUAGE).'</dc:language>'.END_LINE;
echo '<dc:publisher>'.SITE_CITY_NAME.'</dc:publisher>'.END_LINE;
echo '<dc:creator>'.SITE_LINEA_NAME.' (mailto:'.MAIL_LINEA.')'.'</dc:creator>'.END_LINE;
echo '<dc:rights>Copyrights '.date("Y").'</dc:rights>'.END_LINE;
echo '<dc:date>'.date('Y-m-d\\TH:i:s+00:00').'</dc:date>'.END_LINE;
echo '<admin:generatorAgent rdf:resource="'.SITE_LINEA_URL.'"/>'.END_LINE;
echo '<admin:errorReportsTo rdf:resource="mailto:'.SITE_CITY_MAIL.'"/>'.END_LINE;
echo '<sy:updatePeriod>daily</sy:updatePeriod>'.END_LINE;
echo '<sy:updateFrequency>2</sy:updateFrequency>'.END_LINE;
echo '<sy:updateBase>2000-01-01</sy:updateBase>'.END_LINE;

echo '<image rdf:resource="http://www.linea21.com/logo_linea.gif" />'.END_LINE;

# LISTES ITEMS
echo '<items>'.END_LINE;
echo '<rdf:Seq>'.END_LINE;
echo $li_items.END_LINE;
echo '</rdf:Seq>'.END_LINE;
echo '</items>'.END_LINE;
echo '</channel>'.END_LINE;


echo $content;

  
/**
* FOOTER RSS
**********************************************************/

echo '</rdf:RDF>'.END_LINE;
?>
